# 007

|                             | 007-400       |
|:----------------------------|:--------------|
| bindTime                    | 1719439058604 |
| createTime                  | 0             |
| deviceFeatureCode           | 400           |
| deviceFeatureName           | 400有自动风无中风无功率 |
| deviceId                    | <redacted>    |
| deviceNickName              | Dehumidifier  |
| deviceTypeCode              | 007           |
| deviceTypeName              |               |
| offlineState                | 1             |
| puid                        | <redacted>    |
| role                        | 1             |
| roomId                      | 4841165       |
| roomName                    | Living Room   |
| seq                         | 0             |
| statusList.daily_energy_kwh | 0             |
| statusList.f_e_filterclean  | 0             |
| statusList.f_e_pump         | 0             |
| statusList.f_e_push         | 0             |
| statusList.f_e_temp         | 0             |
| statusList.f_e_tubetemp     | 0             |
| statusList.f_e_waterfull    | 0             |
| statusList.f_e_wetsensor    | 0             |
| statusList.f_humidity       | 32            |
| statusList.t_fan_speed      | 2             |
| statusList.t_humidity       | 40            |
| statusList.t_power          | 1             |
| statusList.t_work_mode      | 1             |
| useTime                     | 1719439058583 |
| wifiId                      | <redacted>    |

## Generated from

- [`007`](007-400.json)
